diff -u b/core/modules/config/tests/config_import_test/src/EventSubscriber.php b/core/modules/config/tests/config_import_test/src/EventSubscriber.php
--- b/core/modules/config/tests/config_import_test/src/EventSubscriber.php
+++ b/core/modules/config/tests/config_import_test/src/EventSubscriber.php
@@ -87,7 +87,7 @@
*/
public function onConfigSave(ConfigCrudEvent $event) {
$config = $event->getConfig();
- if ($config->getName() == 'action.settings') {
+ if ($config->getName() == 'system.site') {
$values = $this->state->get('ConfigImportUITest.system.site.weight_select_max', []);
$values[] = $config->get('weight_select_max');
$this->state->set('ConfigImportUITest.system.site.weight_select_max', $values);
@@ -119,9 +119,9 @@
*/
public function onConfigDelete(ConfigCrudEvent $event) {
$config = $event->getConfig();
- if ($config->getName() == 'action.settings') {
- $value = $this->state->get('ConfigImportUITest.action.settings.delete', 0);
- $this->state->set('ConfigImportUITest.action.settings.delete', $value + 1);
+ if ($config->getName() == 'system.site') {
+ $value = $this->state->get('ConfigImportUITest.system.site.delete', 0);
+ $this->state->set('ConfigImportUITest.system.site.delete', $value + 1);
}
}
--- /dev/null
+++ b/core/modules/action/action.install
@@ -0,0 +1,13 @@
+getEditable('action.settings')->delete();
+}
|
diff -u b/core/modules/config/tests/src/Functional/ConfigImportUITest.php b/core/modules/config/tests/src/Functional/ConfigImportUITest.php
--- b/core/modules/config/tests/src/Functional/ConfigImportUITest.php
+++ b/core/modules/config/tests/src/Functional/ConfigImportUITest.php
@@ -114,7 +114,6 @@
$this->assertRaw('
' . $dynamic_name);
$this->assertRaw(' | core.extension');
$this->assertRaw(' | system.theme');
- $this->assertRaw(' | action.settings');
$this->assertFieldById('edit-submit', t('Import all'));
// Import and verify that both do not appear anymore.
@@ -123,7 +122,6 @@
$this->assertNoRaw(' | ' . $dynamic_name);
$this->assertNoRaw(' | core.extension');
$this->assertNoRaw(' | system.theme');
- $this->assertNoRaw(' | action.settings');
$this->assertNoFieldById('edit-submit', t('Import all'));
@@ -157,12 +155,12 @@
$this->assertIdentical($expected, $installed, 'Action, Ban, Text and Options modules installed in the correct order.');
$this->assertTrue(empty($uninstalled), 'No modules uninstalled during import');
// Verify that the action.settings configuration object was only written
// once during the import process and only with the value set in the staged
// configuration. This verifies that the module's default configuration is
// used during configuration import and, additionally, that after installing
// a module, that configuration is not synced twice.
- $recursion_limit_values = \Drupal::state()->get('ConfigImportUITest.action.settings.recursion_limit', []);
+ $recursion_limit_values = \Drupal::state()->get('ConfigImportUITest.system.site.weight_select_max', []);
$this->assertIdentical($recursion_limit_values, [50]);
$core_extension = $this->config('core.extension')->get();
@@ -172,7 +170,6 @@
unset($core_extension['module']['text']);
unset($core_extension['theme']['bartik']);
$sync->write('core.extension', $core_extension);
- $sync->delete('action.settings');
$sync->delete('text.settings');
$system_theme = $this->config('system.theme')->get();
@@ -188,13 +185,11 @@
$this->drupalGet('admin/config/development/configuration');
$this->assertRaw(' | core.extension');
$this->assertRaw(' | system.theme');
- $this->assertRaw(' | action.settings');
// Import and verify that both do not appear anymore.
$this->drupalPostForm(NULL, [], t('Import all'));
$this->assertNoRaw(' | core.extension');
$this->assertNoRaw(' | system.theme');
- $this->assertNoRaw(' | action.settings');
$this->rebuildContainer();
$this->assertFalse(\Drupal::moduleHandler()->moduleExists('ban'), 'Ban module uninstalled during import.');
@@ -213,10 +208,10 @@
$theme_info = \Drupal::service('theme_handler')->listInfo();
$this->assertFalse(isset($theme_info['bartik']), 'Bartik theme uninstalled during import.');
// Verify that the action.settings configuration object was only deleted
// once during the import process.
- $delete_called = \Drupal::state()->get('ConfigImportUITest.action.settings.delete', 0);
- $this->assertIdentical($delete_called, 1, "The action.settings configuration was deleted once during configuration import.");
+ $delete_called = \Drupal::state()->get('ConfigImportUITest.system.site.delete', 0);
+ $this->assertIdentical($delete_called, 1, "The system.site configuration was deleted once during configuration import.");
}
/**
only in patch2:
@@ -157,12 +155,12 @@
$this->assertIdentical($expected, $installed, 'Action, Ban, Text and Options modules installed in the correct order.');
$this->assertTrue(empty($uninstalled), 'No modules uninstalled during import');
- // Verify that the action.settings configuration object was only written
+ // Verify that the system.site configuration object was only written
// once during the import process and only with the value set in the staged
// configuration. This verifies that the module's default configuration is
@@ -213,10 +208,10 @@
$theme_info = \Drupal::service('theme_handler')->listInfo();
$this->assertFalse(isset($theme_info['bartik']), 'Bartik theme uninstalled during import.');
- // Verify that the action.settings configuration object was only deleted
+ // Verify that the system.site configuration object was only deleted
// once during the import process.